@@ -1,6 +1,6 @@
 /*
 --          This file is part of the New World OS and Objectify projects
---         Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  QRW Software
+--      Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010  QRW Software
 --               J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --
 --   This program is free software: you can redistribute it and/or modify
@@ -17,8 +17,11 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
---   For the latest information, source code (SVN), releases, bug and feature
---   request tracking go to:
+--   For the latest information, source code (SVN), releases, and bug tracking
+--   go to:
+--      http://savannah.nongnu.org/projects/objectify
+--
+--   For releases from Alpha_30 and up, bug and feature request tracking go to:
 --      http://sourceforge.net/projects/objectify
 --
 --   For older bug tracking, releases and source code (CVS) prior to the
@@ -36,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-09-20 12:55:11 -0600 (Sun, 20 Sep 2009) $
---   $Revision: 4371 $
+--   $Date: 2010-01-23 08:10:59 -0700 (Sat, 23 Jan 2010) $
+--   $Revision: 4486 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -376,11 +379,8 @@ void nwos_initialize_disk_io(AccessType type, const char* path)
     snprintf(log_msg, sizeof(log_msg), " used public blocks: %llu", nwos_used_public_blocks);
     nwos_log(log_msg);
 
-#ifdef PUBLIC_MODE
-    nwos_word_to_ref(nwos_used_public_blocks, &nwos_next_public_ref);
-
+#ifndef PUBLIC_MODE
     /* don't set read_only flag if in PUBLIC_MODE */
-#else
     read_only = (type == PUBLIC || type == READ_ONLY);
 
 
@@ -494,7 +494,7 @@ bool nwos_terminate_disk_io()
 
 #ifdef PUBLIC_MODE
 	nwos_store_public_data(buffer, sizeof(buffer));
-	snprintf(log_msg, sizeof(log_msg), "  used public blocks: %9u", nwos_ref_to_word(&nwos_next_public_ref));
+	snprintf(log_msg, sizeof(log_msg), "  used public blocks: %llu", nwos_used_public_blocks);
 #else
 	nwos_store_private_data(buffer, sizeof(buffer), nwos_archive_is_file());
 	snprintf(log_msg, sizeof(log_msg), "  total private chunks: %u  used: %u  blocks: %llu", nwos_total_private_chunks, nwos_used_private_chunks, nwos_used_private_blocks);
@@ -548,6 +548,7 @@ bool nwos_terminate_disk_io()
     return disk_was_modified;
 }
 
+#ifndef PUBLIC_MODE
 
 /******************************************************/
 /* This function reads the chunk info table from disk */
@@ -594,6 +595,8 @@ void nwos_write_chunk_info(void* chunk_info, size_t chunk_info_size_in_bytes)
     }
 }
 
+#endif
+
 
 /**********************************************************************************************/
 /* This function returns amount of private space used on disk 0.1 = 10%, 0.5 = 50%, 0.9 = 90% */
