@@ -17,8 +17,11 @@
 --   along with this program, in the file LICENSE.  If not, see 
 --   <http://www.gnu.org/licenses/>.
 --
---   For the latest information, source code (SVN), releases, bug and feature
---   request tracking go to:
+--   For the latest information, source code (SVN), releases, and bug tracking
+--   go to:
+--      http://savannah.nongnu.org/projects/objectify
+--
+--   For releases from Alpha_30 and up, bug and feature request tracking go to:
 --      http://sourceforge.net/projects/objectify
 --
 --   For older bug tracking, releases and source code (CVS) prior to the
@@ -36,8 +39,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-09-20 12:55:11 -0600 (Sun, 20 Sep 2009) $
---   $Revision: 4371 $
+--   $Date: 2010-01-23 08:29:56 -0700 (Sat, 23 Jan 2010) $
+--   $Revision: 4489 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -84,11 +87,12 @@ void nwos_initialize_storage(AccessType type, const char* path)
     nwos_initialize_disk_io(type, path);
 
     /* Read the chunk info file if not a compressed file */
-
+#ifndef PUBLIC_MODE
     if (!nwos_storage_is_public_only() && !nwos_storage_is_compressed_file())
     {
 	nwos_initialize_chunk_info();
     }
+#endif
 
 #ifndef NO_BACKUP
     /* Do a backup file? */
@@ -146,7 +150,9 @@ bool nwos_backup_is_enabled(void)
 
 void nwos_flush_storage(void)
 {
+#ifndef PUBLIC_MODE
     nwos_flush_bit_maps();
+#endif
 }
 
 
@@ -377,7 +383,9 @@ void nwos_write_block(ObjRef* ref, uint8 block[FILE_BLOCK_SIZE])
 	exit(1);
     }
 
+#ifndef PUBLIC_MODE
     nwos_clear_chunk_digest(ref);   /* flag the chunk as modified */
+#endif
 
 #ifndef NO_BACKUP
     nwos_backup_write_block(block);
@@ -421,7 +429,9 @@ void nwos_erase_block(ObjRef* ref)
 
     nwos_write_block_to_offset(Private_Archive, offset, block);
 
+#ifndef PUBLIC_MODE
     nwos_clear_chunk_digest(ref);   /* flag the chunk as modified */
+#endif
 
     nwos_clear_bit_in_map(hash);
 
